@@ -359,12 +359,14 @@ def parse_table_statement(value:_Union[None,str]=None)->_Union[dict,None]:
                 continue
             new_data[k] = v
         new_data = _obj.set_defaults(defaults,new_data)
+        
         if new_data['action'] == "create":
             cols = capture_create_table_columns(value)
             # new_data['column_data'] = _obj.strip_list_nulls([parse_column_data(x) for x in cols])
             d = _parse_table_column_lines(cols)
             new_data["columns"] = d['columns']
             new_data["primary_keys"] = d['primary_keys']
+            new_data["unique_keys"] = d['unique_keys']
             new_data["keys"] = d['keys']
             new_data["constraints"] = d['constraints']
         # print(new_data)
@@ -376,6 +378,7 @@ def _parse_table_column_lines(lines):
     data = {
         "columns":[],
         "primary_keys":[],
+        "unique_keys":[],
         "keys":[],
         "constraints":[],
     }
@@ -386,6 +389,13 @@ def _parse_table_column_lines(lines):
         if is_line_key(line):
             # print(f"key found: {line} {parse_key(line)}")
             data['keys'] = _lu.append(data['keys'],parse_key(line))
+            
+            uk = parse_unique_key(line)
+            if uk is not None:
+                # print(f"Unique Key Found: {uk}")
+                data['unique_keys'].append(uk)
+                # data['unique_keys'] = _lu.append(data['unique_keys'],uk['unique_key'])
+
             pk = parse_primary_key(line)
             if pk is not None:
                 data['primary_keys'] = _lu.append(data['primary_keys'],pk['primary_key'])
@@ -403,6 +413,9 @@ def _parse_table_column_lines(lines):
         c['is_primary_key'] = False
         if c['name'] in data['primary_keys']:
             c['primary_key'] = True
+
+
+
     return data
 
 def capture_create_table_columns(sql):
@@ -435,8 +448,10 @@ def capture_create_table_columns(sql):
     scanner = originalTextFor(nestedExpr('(',')'))
     for match in scanner.searchString(sql):
         val = _csu.strip(match[0],["(",")"])
-        val = _sql.escape_quoted_chars(val,True)
+        
+        # val = _sql.escape_quoted_chars(val,True,['__%0A__'])
         output = val.split("\n")
+        output = [_sql.escape_quoted_chars(x,True) for x in output]
     return output
 
 
@@ -490,7 +505,7 @@ def parse_key(value=None):
     paren_word_list = _open_paren + Word(alphanums + "_,'\"` ") + _close_paren
 
     # KEY `FK_ActivityLogs_RequestLogID`
-    key_name = Suppress(CaselessKeyword('KEY')) + quoted_word.setResultsName('key_name')
+    key_name = Optional(CaselessKeyword('unique')) + Suppress(CaselessKeyword('KEY')) + quoted_word.setResultsName('key_name')
 
     foreign_col_name = paren_word_list.setResultsName('foreign_col_name').setParseAction(_parse_list)
 
@@ -548,6 +563,54 @@ def parse_primary_key(value=None):
         output = new_data
     return output
 
+
+def parse_unique_key(value=None):
+    
+    if 'unique key' not in value.lower():
+        return None
+# UNIQUE KEY `Unique_barnBlocks_barnID_userID_3006` (`user_id`, `barn_id`) COMMENT 'Unique constraint to ensure a barn cannot block the same user multiple times.',
+
+    _tick,_double_quote,_single_quote,_period = [Suppress(x) for x in list('`"\'.')]
+    _quote = (_tick|_double_quote|_single_quote)
+    _open_paren,_close_paren = [Suppress(x) for x in list('()')]
+    paren_word = _open_paren + Optional(_quote) + Word(alphanums + "_") + Optional(_quote) + _close_paren
+    quoted_word = _quote + Word(alphanums + "_") + _quote
+
+
+    paren_word_list = _open_paren + Word(alphanums + "_,'\"` ") + _close_paren
+    unique_key = paren_word_list.setResultsName('columns').setParseAction(_parse_list)
+    key_name = quoted_word.setResultsName('constraint_name')
+
+    comment = None
+    match = _re.findall(r"comment\s*'([^']*)",value,_re.IGNORECASE)
+    if isinstance(match,(list)) and len(match) > 0:
+        comment = match[0]
+
+    grammar = Suppress(CaselessKeyword('unique key')) + key_name + unique_key
+    res = ZeroOrMore(Group(grammar).setResultsName('data')).parseString(value)
+
+    output = None
+
+    if len(res) > 0:
+        data = res.as_dict()['data']
+        
+        new_data = {
+            "comment":comment
+        }
+        for k,v in data.items():
+            if k == "columns":
+                new_data[k] = v.split(",")
+                continue
+            if isinstance(v,(list)):
+                new_data[k] = v[0]
+                continue
+            new_data[k] = v
+        # print(f"Unique Key Data: {new_data}")
+        # print(new_data)
+        output = new_data
+    return output
+
+
 def parse_constraint(value:str):
     '''
         Parse constraint data from the string.
@@ -600,10 +663,17 @@ def parse_constraint(value:str):
     res = ZeroOrMore(Group(grammar).setResultsName('data')).parseString(value)
 
     output = None
+    
+    comment = None
+    match = _re.findall(r"comment\s*'([^']*)",value,_re.IGNORECASE)
+    if isinstance(match,(list)) and len(match) > 0:
+        comment = match[0]    
 
     if len(res) > 0:
         data = res.as_dict()['data']
-        new_data = {}
+        new_data = {
+            "comment":comment
+        }
         for k,v in data.items():
             if isinstance(v,(list)):
                 new_data[k] = v[0]
@@ -694,6 +764,7 @@ def parse_table_columns(sql):
                         "comment":None,
                         "shlexed":None,
                         "is_primary_key":False,
+                        "is_unique":False,
                     }
                     # print (f"raw_type: {data['raw_type']}")
                     data['shlexed'] = _shlex.split(data['raw_type'])
@@ -701,6 +772,7 @@ def parse_table_columns(sql):
                     # print (f"column: {c_name}")
                     if data['name'] in file_data['primary_keys']:
                         data['is_primary_key'] = True
+                    
                     data = parse_col_type(data)
                     data = parse_allow_null(data)
                     data = parse_col_comment(data)
@@ -1010,11 +1082,20 @@ def strip_keys_constraints(sql):
 
     if len(output['keys']) > 0:
         primary_keys = []
+        unique_keys = []
         for k in output['keys']:
             data = parse_primary_keys(k)
             if len(data) > 0:
                 primary_keys = data
+                continue
+
+            uk_data = parse_unique_key(k)
+            if uk_data is not None:
+                print(f"Unique Key successfully parsed.")
+                unique_keys.append(uk_data)
+                continue
         output['primary_keys'] = primary_keys
+        output['unique_keys'] = unique_keys
 
     if len(output['constraints']) > 0:
         foreign_keys = []
@@ -1023,10 +1104,12 @@ def strip_keys_constraints(sql):
             if data is not None:
                 foreign_keys.append(data)
                 continue
+
             data = parse_key(k)
             if data is not None:
                 foreign_keys.append(data)
                 continue
+
         output['foreign_keys'] = foreign_keys
 
     return output
