@@ -588,7 +588,7 @@ def escape_quoted_commas(value,escape_value="__ESCAPED_COMMA__",reverse=False):
     # print(sql_qs.search_string(value))
     return value
 
-def escape_quoted_chars(value,reverse=False):
+def escape_quoted_chars(value,reverse=False,ignore=None):
     '''
         Escape characters that can effect parsing which are located within quotes.
 
@@ -602,6 +602,7 @@ def escape_quoted_chars(value,reverse=False):
         `reverse` {bool}
             if True it will reverse the escaped chars with their actual chars.
 
+
         Return {str}
         ----------------------
         The string with escaped chars.
@@ -624,16 +625,20 @@ def escape_quoted_chars(value,reverse=False):
         ["`","__&#96__"],
         ['"',"__&#34__"],
         ["'","__&#39__"],
+        ["\n","__%0A__"],
     ]
 
+    ignore = _lu.force_list(ignore)
+
 
     if reverse is True:
         for e in escapes:
-            value = value.replace(e[1],e[0])
+            if e[1] not in ignore:
+                value = value.replace(e[1],e[0])
         return value
 
     for e in escapes:
-        sql_qs = QuotedString("'", esc_quote="''")
+        sql_qs = QuotedString("'", esc_quote="''",multiline=True)
         quote = sql_qs.search_string(value)
         if len(quote) > 0:
             quote = quote.asList()
